@@ -620,9 +620,18 @@ netstatus_dialog_setup_device_support (NetstatusDialogData *data,
 static void
 netstatus_dialog_set_icon (GtkWidget *dialog)
 {
-  gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-				 NETSTATUS_ICONDIR "/gnome-netstatus-tx.png",
-				 NULL);
+  GtkIconTheme *icon_theme;
+  GtkIconInfo  *icon_info;
+
+  icon_theme = gtk_icon_theme_get_for_screen (gtk_window_get_screen (GTK_WINDOW (dialog)));
+
+  if ((icon_info = gtk_icon_theme_lookup_icon (icon_theme, "gnome-netstatus-tx", 48, 0)))
+    {
+      gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
+				     gtk_icon_info_get_filename (icon_info),
+				     NULL);
+      gtk_icon_info_free (icon_info);
+    }
 }
 
 static gboolean
