@@ -34,6 +34,7 @@
 struct _NetstatusIconPrivate
 {
   GtkWidget      *image;
+  GtkWidget      *error_dialog;
 
   NetstatusIface *iface;
   NetstatusState  state;
@@ -289,6 +290,10 @@ netstatus_icon_destroy (GtkObject *widget)
 {
   NetstatusIcon *icon = (NetstatusIcon *) widget;
 
+  if (icon->priv->error_dialog)
+    gtk_widget_destroy (icon->priv->error_dialog);
+  icon->priv->error_dialog = NULL;
+
   if (icon->priv->state_changed_id)
     {
       g_assert (icon->priv->iface != NULL);
@@ -599,24 +604,44 @@ netstatus_icon_invoke (NetstatusIcon *icon)
 
   if (netstatus_iface_get_state (icon->priv->iface) != NETSTATUS_STATE_ERROR)
     {
+      if (icon->priv->error_dialog)
+	gtk_widget_destroy (icon->priv->error_dialog);
+      icon->priv->error_dialog = NULL;
+
       g_signal_emit (icon, icon_signals [INVOKED], 0);
     }
   else
     {
       const GError *error;
-      GtkWidget    *dialog;
 
       error = netstatus_iface_get_error (icon->priv->iface);
       g_assert (error != NULL);
 
-      dialog = gtk_message_dialog_new (NULL, 0,
-				       GTK_MESSAGE_ERROR,
-				       GTK_BUTTONS_CLOSE,
-				       _("Please contact your system administrator to resolve the following problem:\n\n%s"),
-				       error->message);
+      if (icon->priv->error_dialog)
+        {
+	  gtk_window_set_screen (GTK_WINDOW (icon->priv->error_dialog),
+				 gtk_widget_get_screen (GTK_WIDGET (icon)));
+          gtk_window_present (GTK_WINDOW (icon->priv->error_dialog));
+          return;
+        }
 
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
+      icon->priv->error_dialog =
+	gtk_message_dialog_new (NULL, 0,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_CLOSE,
+				_("Please contact your system administrator to resolve the following problem:\n\n%s"),
+				error->message);
+
+      gtk_window_set_screen (GTK_WINDOW (icon->priv->error_dialog),
+			     gtk_widget_get_screen (GTK_WIDGET (icon)));
+
+      g_signal_connect (icon->priv->error_dialog, "response",
+			G_CALLBACK (gtk_widget_destroy), NULL);
+      g_signal_connect (icon->priv->error_dialog, "destroy",
+                        G_CALLBACK (gtk_widget_destroyed),
+			&icon->priv->error_dialog);
+
+      gtk_widget_show (icon->priv->error_dialog);
     }
 }
 
