@@ -33,6 +33,10 @@
 #include <libgnome/gnome-i18n.h>
 
 #include <sys/ioctl.h>
+#ifdef HAVE_SYS_SOCKIO_H
+#include <sys/sockio.h>
+#endif /* HAVE_SYS_SOCKIO_H */
+#include <sys/param.h>
 #include <net/if.h>
 #include <net/if_arp.h>
 #include <arpa/inet.h>
